/*
 * An opener for a "host" file provided via the C library.
 *
 * Copyright (C) 2021 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#include <sys/stat.h>

#include "host_file_accessor.h"
#include "host_file_opener.h"

/* Return a file identifier for the given 'path'. */

fileid_t HostFileOpener::get_fileid(const char *path)
{
    struct stat statbuf;

    /* Obtain the inode number.
       NOTE: This does not handle errors! */

    stat(path, &statbuf);

    return statbuf.st_ino;
}

/* Return a new accessor for 'fileid'. */

Accessor *HostFileOpener::make_accessor(const char *path, fileid_t fileid)
{
    FILE *fp = fopen(path, "r");

    if (fp == NULL)
        return NULL;

    return new HostFileAccessor(fp, fileid);
}

// vim: tabstop=4 expandtab shiftwidth=4
